@@ -1,12 +1,3 @@
-# import os.path, sys
-#
-# f = __file__
-# for _ in range(6): # dirty hack to make custom Beam modules work in Airflow
-#     f = os.path.dirname(f)
-# sys.path.insert(0, f)
-#
-# os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = "/opt/airflow/google-configs/carbide-program-314404-b1f3be733966.json"
-
 import argparse
 
 import apache_beam as beam
@@ -21,6 +12,12 @@ import logging
 from org.codeforrussia.selector.standardizer.standardizer_registry_factory import SupportedInputFormat, StandardizerRegistryFactory
 from org.codeforrussia.selector.standardizer.schemas.schema_registry_factory import StandardProtocolSchemaRegistryFactory
 
+def add_gcp_connection(pipeline_options: PipelineOptions):
+    if pipeline_options.google_application_credentials is not None:
+        import os
+        os.environ["GOOGLE_APPLICATION_CREDENTIALS"] = pipeline_options.google_application_credentials
+
+
 def run(argv=None, save_main_session=True):
     parser = argparse.ArgumentParser()
 
@@ -50,6 +47,7 @@ def run(argv=None, save_main_session=True):
     standardizer = StandardizerRegistryFactory.get_standardizer_registry(schema_registry_factory=StandardProtocolSchemaRegistryFactory).get_standardizer(known_args.input_data_format)
 
     pipeline_options = PipelineOptions(pipeline_args)
+    add_gcp_connection(pipeline_options)
     pipeline_options.view_as(SetupOptions).save_main_session = save_main_session
 
     with beam.Pipeline(options=pipeline_options) as p:
